==> 0.1.90.tar.gz: lib/pages/source_page.dart <==
import 'package:feed_plugin/utilities/colors.dart';
import 'package:feed_plugin/widgets/camera_button_widget.dart';
import 'package:feed_plugin/widgets/gallery_button_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class SourcePage extends StatelessWidget {
  const SourcePage({Key key, this.loc}) : super(key: key);

  final loc;
  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
        textDirection: TextDirection.ltr,
        child: ScreenUtilInit(
          designSize: Size(width, height),
          allowFontScaling: false,
          builder: () => Scaffold(
            appBar: PreferredSize(
                preferredSize: Size.fromHeight(70.0),
                child: AppBar(
                  title: Padding(
                    padding: EdgeInsets.only(
                        left: ScreenUtil().setWidth(60),
                        top: ScreenUtil().setWidth(9)),
                    child: Text(loc.translate('Select Source')),
                  ),
                  backgroundColor: primaryColor,
                )),
            body: Directionality(
              textDirection: TextDirection.ltr,
              child: ListView(
                children: [
                  CameraButtonWidget(loc: loc),
                  GalleryButtonWidget(loc: loc),
                ],
              ),
            ),
          ),
        ));
  }
}

==> 0.2.18.tar.gz: lib/pages/source_page.dart <==
import 'package:feed_plugin/widgets/camera_button_widget.dart';
import 'package:feed_plugin/widgets/gallery_button_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class SourcePage extends StatelessWidget {
  const SourcePage({Key key, this.loc}) : super(key: key);

  final loc;
  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
        textDirection: TextDirection.ltr,
        child: ScreenUtilInit(
          designSize: Size(width, height),
          allowFontScaling: false,
          builder: () => Scaffold(
            appBar: PreferredSize(
                preferredSize: Size.fromHeight(70.0),
                child: AppBar(
                  title: Padding(
                    padding: EdgeInsets.only(
                        left: ScreenUtil().setWidth(60),
                        top: ScreenUtil().setWidth(9)),
                    child: Text(loc.translate('Select Source')),
                  ),
                  backgroundColor: Color(0xFF083356),
                )),
            body: Directionality(
              textDirection: TextDirection.ltr,
              child: ListView(
                children: [
                  CameraButtonWidget(loc: loc),
                  GalleryButtonWidget(loc: loc),
                ],
              ),
            ),
          ),
        ));
  }
}
